/*
 *  This file is part of uIRC. (https://git.redxen.eu/caskd/uIRC)
 *  Copyright (c) 2019-2021 Alex-David Denes
 *
 *  uIRC is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  any later version.
 *
 *  uIRC is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with uIRC.  If not, see <https://www.gnu.org/licenses/>.
 */

#include "validators.h"

#include <assert.h> // assert()
#include <stdio.h>  // NULL
#include <string.h> // strchr()

size_t
uirc_validator_string_nocrlf(const char* str)
{
	assert(str != NULL);
	const char* save = str;
	for (; *str; str++) {
		if (*str == '\r' || *str == '\n') return 0;
	}
	return (size_t)(str - save);
}

size_t
uirc_validator_string_nospcl(const char* str)
{
	assert(str != NULL);
	const char* save = str;
	for (; *str; str++) {
		if (*str == ' ' || *str == ':') return 0;
	}
	return (size_t)(str - save);
}

size_t
uirc_validator_string_noblcm(const char* str)
{
	assert(str != NULL);
	const char* save = str;
	for (; *str; str++) {
		if (*str == '\a' || *str == ',') return 0;
	}
	return (size_t)(str - save);
}

// TODO: Make this read only
// TODO: Improve the logic for this
size_t
uirc_validator_buffer_channel(char* chan)
{
	assert(chan != NULL);
	if (*chan != '#' && *chan != '+' && *chan != '!' && *chan != '&') return 0;
	const char* save = chan;
	char*       clps = ++chan;
	if ((clps = strchr(chan, ':')) != NULL) {
		*clps = '\0';
		if (uirc_validator_string_nospcl(chan) != 1 || uirc_validator_string_nocrlf(chan) != 1 || uirc_validator_string_noblcm(chan) != 1) {
			*clps = ':';
			return 0;
		}
		*clps = ':';
		chan  = ++clps;
	}
	if (uirc_validator_string_nospcl(chan) != 1 || uirc_validator_string_nocrlf(chan) != 1 || uirc_validator_string_noblcm(chan) != 1) return 0;
	return (size_t)(save - chan);
}

// TODO: Work on the logic for this
signed short
uirc_validator_message(IRC_Message* mesg)
{
	assert(mesg != NULL);
	for (unsigned int i = 0; mesg->args[i] != NULL; i++) {
		if (Val_type_nocrlf(mesg->args[i]) != 1) return ERR_UIRC_VAL_FAILED;
		if (!(mesg->args[i + 1] == NULL && mesg->trailing)) {
			if (Val_type_nospcl(mesg->args[i]) != 1) return ERR_UIRC_VAL_FAILED;
		}
	}
	return 1;
}

